//
// timezone-make-one-win-link.cpp
//
// Bill Seymour, 2024-03-02
//
// This is the function that creates a single symbolic link in a Windows
// file system.  It's used by one of the optional preparation steps when
// using Bill's time zone class with Zoneinfo's TZif files on Windows
// (see https://www.cstdbill.com/civil-time/timezone.html);
//
// This is the native Windows call that's needed if you don't have
// a C++17 compiler and standard library.  It's in a source file
// of its own because it requires the whole <windows.h> zoo,
// and we don't want that to pollute the main program.
//
// This file is in the public domain.
//

#include "timezone-win-links.hpp" // includes <string>

#include <windows.h>

namespace timezone_win {

bool make_symlink(const std::string& link_path, const std::string& real_path)
{
    return CreateSymbolicLinkA(link_path.c_str(),
                               real_path.c_str(),
                               SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE);
}

} // namespace timezone_win

// End of timezone-make-one-win-link.cpp
